@@ -587,7 +587,7 @@ int msqlConnect(host)
 	/*
 	** Send the username for this process for ACL checks
 	*/
-	pw = getpwuid(getuid());
+	pw = getpwuid(geteuid());
 	if (!pw)
 	{
 		strcpy(msqlErrMsg,USERNAME_ERROR);
