@@ -286,7 +286,7 @@ editQuery(q)
 		combuf[1024];
 	int	fd;
 
-	filename = tmpnam(NULL);
+	filename = (char *)msql_tmpnam(NULL);
 	fd = open(filename,O_CREAT | O_WRONLY, 0777);
 	editor = (char *)getenv("VISUAL");
 	if (!editor)
