@@ -392,16 +392,8 @@ int msqlAddField(ident,type,length,notNull,priKey)
 
 	msqlTrace(TRACE_IN,"msqlAddField()");
 
-	if (*(ident->seg2))
-	{
-		name = ident->seg2;
-		table = ident->seg1;
-	}
-	else
-	{
-		name = ident->seg1;
-		table = NULL;
-	}
+	name = ident->seg2;
+	table = ident->seg1;
 
 
 	/*
