@@ -148,7 +148,8 @@ initServer()
 {
 	int	sock,
 		tcpPort,
-		addrLen;
+		addrLen,
+		opt;
 	struct	sockaddr_in	IPaddr;
 	struct	servent		*serv_ptr;
 	char	*envVar;
@@ -176,6 +177,11 @@ initServer()
 		perror("Can't start server : IP Socket ");
 		exit(1);
 	}
+#ifdef SO_REUSEADDR
+	opt = 1;
+	setsockopt(IPsock, SOL_SOCKET, SO_REUSEADDR, &opt, sizeof(int));
+#endif
+
 	(void)bzero(&IPaddr, sizeof(IPaddr));
 	IPaddr.sin_family = AF_INET;
 	IPaddr.sin_addr.s_addr = htonl(INADDR_ANY);
@@ -405,6 +411,7 @@ main(argc,argv)
 	setupSignals();
 	msqlLoadAcl(1);
 	(void)bzero(&clientFDs,sizeof(fd_set));
+	(void)bzero(conArray,sizeof(conArray));
 	msqlDebug(MOD_GENERAL,"miniSQL debug mode.  Waiting for connections.\n");
 	while(1)
 	{
@@ -550,6 +557,7 @@ main(argc,argv)
 					FD_SET(newSock,&clientFDs);
 					uname = (char *)strtok(packet,"\n");
 					msqlDebug(MOD_GENERAL,"User = %s\n",uname);
+					safeFree(conArray[newSock].user);
 					conArray[newSock].user = (char *)
 						strdup(uname);
 					sprintf(packet,"-100:\n");
@@ -656,6 +664,7 @@ main(argc,argv)
 				curSock = comSock;
 				msqlListFields(comSock,
 					arg,conArray[comSock].db);
+				safeFree(arg);
 				break;
 
 			    case QUIT:
@@ -683,6 +692,7 @@ main(argc,argv)
 					"\n\r");
 				arg = (char *)strdup(cp);
 				msqlCreateDB(comSock,arg);
+				safeFree(arg);
 				break;
 
 			    case DROP_DB:	
@@ -695,6 +705,7 @@ main(argc,argv)
 					"\n\r");
 				arg = (char *)strdup(cp);
 				msqlDropDB(comSock,arg);
+				safeFree(arg);
 				break;
 
 			    case RELOAD_ACL:
